Integrating with Django Reversion — Django Stories v0.5.1 documentation

Django Stories v0.5.1 documentation

# Integrating with Django Reversion

- Table of Contents
- index
  modules
  next
  previous

# Integrating with Django Reversion

1. Install django-reversion

       pip install django-reversion

2. Add `reversion` to your `INSTALLED_APPS` setting.

3. `./manage.py syncdb`

4. Set `STORY_SETTINGS['USE_REVERSION'] = True`

Versions are tracked from when reversion is first installed.